@@ -54,7 +54,7 @@
 #' cores that are available for the current R session.
 #'
 #' @export
-multisession <- function(expr, envir=parent.frame(), substitute=TRUE, lazy=FALSE, seed=NULL, globals=TRUE, persistent=FALSE, workers=availableCores(), gc=FALSE, earlySignal=FALSE, label=NULL, ...) {
+multisession <- function(expr, envir = parent.frame(), substitute = TRUE, lazy = FALSE, seed = NULL, globals = TRUE, persistent = FALSE, workers = availableCores(), gc = FALSE, earlySignal = FALSE, label = NULL, ...) {
   if ("maxCores" %in% names(list(...))) {
     .Defunct(msg = "Argument 'maxCores' has been renamed to 'workers'. Please update you script/code that uses the future package.")
   }
@@ -63,19 +63,16 @@ multisession <- function(expr, envir=parent.frame(), substitute=TRUE, lazy=FALSE
   workers <- as.integer(workers)
   stopifnot(length(workers) == 1, is.finite(workers), workers >= 1)
 
-  ## Fall back to lazy uniprocess futures if only a single R session can be used,
+  ## Fall back to lazy sequential futures if only a single R session can be used,
   ## i.e. the use the current main R process.
   if (workers == 1L) {
     ## FIXME: How to handle argument 'persistent'? /HB 2016-03-19
-    return(uniprocess(expr, envir=envir, substitute=FALSE, lazy=TRUE, seed=seed, globals=globals, local=TRUE, label=label))
+    return(sequential(expr, envir = envir, substitute = FALSE, lazy = TRUE, seed = seed, globals = globals, local = TRUE, label = label))
   }
 
-  ## IMPORTANT: When we setup a multisession cluster, we need to
-  ## account for the main R process as well, i.e. we should setup
-  ## a cluster with one less process.
-  workers <- ClusterRegistry("start", workers=workers-1L)
+  workers <- ClusterRegistry("start", workers = workers)
 
-  future <- MultisessionFuture(expr=expr, envir=envir, substitute=FALSE, lazy=lazy, seed=seed, globals=globals, persistent=persistent, workers=workers, gc=gc, earlySignal=earlySignal, label=label, ...)
+  future <- MultisessionFuture(expr = expr, envir = envir, substitute = FALSE, lazy = lazy, seed = seed, globals = globals, persistent = persistent, workers = workers, gc = gc, earlySignal = earlySignal, label = label, ...)
   if (!future$lazy) future <- run(future)
   invisible(future)
 }
