@@ -1,4 +1,4 @@
-signalEarly <- function(future, collect=TRUE, ...) {
+signalEarly <- function(future, collect = TRUE, ...) {
   ## Future is not yet launched
   if (future$state == "created") return(future)
 
@@ -7,24 +7,27 @@ signalEarly <- function(future, collect=TRUE, ...) {
   ## Don't signal early?
   if (!earlySignal) return(future)
 
-  mdebug("signalEarly(): Retrieving value ...")
+  debug <- getOption("future.debug", FALSE)
+  if (debug) mdebug("signalEarly(): Retrieving value ...")
 
   ## Collect value?
   if (collect) {
-    mdebug("signalEarly(): v <- value(f, signal=FALSE)")
-    value <- value(future, signal=FALSE)
+    if (debug) mdebug("signalEarly(): v <- value(f, signal = FALSE)")
+    value <- value(future, signal = FALSE)
   } else {
-    mdebug("signalEarly(): v <- f$value")
+    if (debug) mdebug("signalEarly(): v <- f$value")
     value <- future$value
   }
 
-  mdebug("signalEarly(): class(v) = c(%s)", paste(sQuote(class(value)), collapse=", "))
-  mdebug("signalEarly(): Retrieving value ... DONE")
+  if (debug) {
+    mdebug("signalEarly(): class(v) = c(%s)", paste(sQuote(class(value)), collapse = ", "))
+    mdebug("signalEarly(): Retrieving value ... DONE")
+  }
 
   ## Was a condition caught?
   if (!inherits(value, "condition")) return(future)
 
-  mdebug("signalEarly(): signalCondition(v)")
+  if (debug) mdebug("signalEarly(): signalCondition(v)")
 
   ## Signal detected condition
   if (inherits(value, "error")) {
@@ -38,7 +41,7 @@ signalEarly <- function(future, collect=TRUE, ...) {
     signalCondition(value)
   }
 
-  mdebug("signalEarly() ... DONE")
+  if (debug) mdebug("signalEarly() ... DONE")
 
   invisible(future)
 }
