@@ -1,11 +1,16 @@
 source("incl/start.R")
-library("future")
 
 message("*** rng ...")
 
+## A valid L'Ecuyer-CMRG RNG seed
+seed <- c(407L, 1420090545L, 65713854L, -990249945L,
+          1780737596L, -1213437427L, 1082168682L)
+f <- Future(42, seed = seed)
+print(f)
+
 ## See Section 6 on 'Random-number generation' in
-## vignette("parallel", package="parallel")
-fsample <- function(x, size=4L, seed=NULL, what = c("future", "%<-%")) {
+## vignette("parallel", package = "parallel")
+fsample <- function(x, size = 4L, seed = NULL, what = c("future", "%<-%")) {
   what <- match.arg(what)
   
   ## Must use session-specific '.GlobalEnv' here
@@ -19,11 +24,11 @@ fsample <- function(x, size=4L, seed=NULL, what = c("future", "%<-%")) {
     ## Reset state of random seed afterwards?
     on.exit({
       if (is.null(oseed)) {
-        rm(list=".Random.seed", envir=.GlobalEnv, inherits=FALSE)
+        rm(list = ".Random.seed", envir = .GlobalEnv, inherits = FALSE)
       } else {
         .GlobalEnv$.Random.seed <- oseed
       }
-    }, add=TRUE)
+    }, add = TRUE)
 
     set.seed(seed)
   }
@@ -34,14 +39,14 @@ fsample <- function(x, size=4L, seed=NULL, what = c("future", "%<-%")) {
     fs <- list()
     for (ii in seq_len(size)) {
       .seed <- parallel::nextRNGStream(.seed)
-      fs[[ii]] <- future({ sample(x, size=1L) }, seed = .seed)
+      fs[[ii]] <- future({ sample(x, size = 1L) }, seed = .seed)
     }
     res <- values(fs)
   } else {
     res <- listenv::listenv()
     for (ii in seq_len(size)) {
       .seed <- parallel::nextRNGStream(.seed)
-      res[[ii]] %<-% { sample(x, size=1L) } %seed% .seed
+      res[[ii]] %<-% { sample(x, size = 1L) } %seed% .seed
     }
     res <- as.list(res)
   }
@@ -50,22 +55,22 @@ fsample <- function(x, size=4L, seed=NULL, what = c("future", "%<-%")) {
 } # fsample()
 
 
-dummy <- sample(0:9, size=1L)
+dummy <- sample(0:9, size = 1L)
 seed0 <- .Random.seed
 
 ## Reference sample with fixed random seed
-plan("uniprocess")
-y0 <- fsample(0:9, seed=42L)
+plan("sequential")
+y0 <- fsample(0:9, seed = 42L)
 
 ## Assert that random seed is reset
 stopifnot(identical(.GlobalEnv$.Random.seed, seed0))
 
 
-for (cores in 1:min(3L, availableCores())) {
+for (cores in 1:availCores) {
   message(sprintf("Testing with %d cores ...", cores))
-  options(mc.cores=cores-1L)
+  options(mc.cores = cores)
 
-  for (strategy in supportedStrategies()) {
+  for (strategy in supportedStrategies(cores)) {
     message(sprintf("%s ...", strategy))
 
     plan(strategy)
@@ -74,7 +79,7 @@ for (cores in 1:min(3L, availableCores())) {
       .GlobalEnv$.Random.seed <- seed0
 
       ## Fixed random seed
-      y1 <- fsample(0:9, seed=42L, what = what)
+      y1 <- fsample(0:9, seed = 42L, what = what)
       print(y1)
       stopifnot(identical(y1, y0))
   
@@ -82,7 +87,7 @@ for (cores in 1:min(3L, availableCores())) {
       stopifnot(identical(.GlobalEnv$.Random.seed, seed0))
   
       ## Fixed random seed
-      y2 <- fsample(0:9, seed=42L, what = what)
+      y2 <- fsample(0:9, seed = 42L, what = what)
       print(y2)
       stopifnot(identical(y2, y1))
       stopifnot(identical(y2, y0))
